@@ -231,16 +231,19 @@ class Microservices(BaseClass, ABC):
         """
         return base64.b64encode(str.encode(json.dumps(json_in)))
 
-    def without_response(self, topic, data):
+    def without_response(self, topic, data={}, id_transaction=None):
         """
             Metodo para el envio de una peticion a un topico, sin esperar
             una respuesta del mismo.
         """
+        id_trans = id_transaction if id_transaction is None else str(
+            uuid.uuid4())
+
         self._send(topic, {
             "metadata": {
                 "uuid": None,
                 "id_operacion": str(uuid.uuid4()),
-                "id_transaction": str(uuid.uuid4()),
+                "id_transaction": id_trans,
                 "intents": 1,
                 "callback": None,
                 "callbacks": [],
@@ -260,7 +263,7 @@ class Microservices(BaseClass, ABC):
             },
             "data": data,
             "headers": {}
-        }, str(uuid.uuid4()))
+        }, id_trans)
 
     def _message(self, msg):
         """
